from django.db import models

from django_tiptap.fields import TipTapTextField


# Create your models here.
class Note(models.Model):
    content = TipTapTextField()
    somethingMore = TipTapTextField(null=True)



# Generated by Django 3.2 on 2021-04-19 14:21

from django.db import migrations, models

import django_tiptap.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Note",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("content", django_tiptap.fields.TipTapTextField()),
            ],
        ),
    ]



from django.db import models
from django.forms import fields

from .widgets import TipTapWidget


class TipTapTextFormField(fields.CharField):
    def __init__(self, *args, **kwargs):
        kwargs.update({"widget": TipTapWidget()})
        super().__init__(*args, **kwargs)


class TipTapTextField(models.TextField):
    def formfield(self, **kwargs):
        return super().formfield(form_class=TipTapTextFormField, **kwargs)



"""
Django settings for django_tiptap project.

Generated by 'django-admin startproject' using Django 3.2.

For more information on this file, see
https://docs.djangoproject.com/en/3.2/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/3.2/ref/settings/
"""

from pathlib import Path

# Build paths inside the project like this: BASE_DIR / 'subdir'.
BASE_DIR = Path(__file__).resolve().parent.parent


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/3.2/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = "django-insecure-qx8%yn$yy1@!^+xxzjp-oiu-1=hao4yucza5ljym!zxuadu8)7"

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = True

ALLOWED_HOSTS = []


# Application definition

INSTALLED_APPS = [
    "django.contrib.admin",
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.sessions",
    "django.contrib.messages",
    "django.contrib.staticfiles",
    "django_tiptap",
    "django_tiptap_demo.demo_app",
]

MIDDLEWARE = [
    "django.middleware.security.SecurityMiddleware",
    "django.contrib.sessions.middleware.SessionMiddleware",
    "django.middleware.common.CommonMiddleware",
    "django.middleware.csrf.CsrfViewMiddleware",
    "django.contrib.auth.middleware.AuthenticationMiddleware",
    "django.contrib.messages.middleware.MessageMiddleware",
    "django.middleware.clickjacking.XFrameOptionsMiddleware",
]

ROOT_URLCONF = "django_tiptap_demo.urls"

TEMPLATES = [
    {
        "BACKEND": "django.template.backends.django.DjangoTemplates",
        "DIRS": [],
        "APP_DIRS": True,
        "OPTIONS": {
            "context_processors": [
                "django.template.context_processors.debug",
                "django.template.context_processors.request",
                "django.contrib.auth.context_processors.auth",
                "django.contrib.messages.context_processors.messages",
            ],
        },
    },
]

WSGI_APPLICATION = "django_tiptap_demo.wsgi.application"


# Database
# https://docs.djangoproject.com/en/3.2/ref/settings/#databases

DATABASES = {
    "default": {
        "ENGINE": "django.db.backends.sqlite3",
        "NAME": str(BASE_DIR / "db.sqlite3"),
    }
}


# Password validation
# https://docs.djangoproject.com/en/3.2/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        "NAME": "django.contrib.auth.password_validation.UserAttributeSimilarityValidator",
    },
    {"NAME": "django.contrib.auth.password_validation.MinimumLengthValidator"},
    {"NAME": "django.contrib.auth.password_validation.CommonPasswordValidator"},
    {"NAME": "django.contrib.auth.password_validation.NumericPasswordValidator"},
]


# Internationalization
# https://docs.djangoproject.com/en/3.2/topics/i18n/

LANGUAGE_CODE = "en-us"

TIME_ZONE = "UTC"

USE_I18N = True

USE_L10N = True

USE_TZ = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/3.2/howto/static-files/

STATIC_URL = "/static/"

# Default primary key field type
# https://docs.djangoproject.com/en/3.2/ref/settings/#default-auto-field

DEFAULT_AUTO_FIELD = "django.db.models.BigAutoField"


DJANGO_TIPTAP_CONFIG = {
    "width": "500px",
    "height": "500px",
    "extensions": [
        "bold",
        "italic",
        "underline",
        "strikethrough",
        "h1",
        "h2",
        "h3",
        "h4",
        "h5",
        "h6",
        "textAlign",
        "indent",
        "table",
        "bulletList",
        "orderedList",
        "typography",
        "clearFormat",
        "jinjaSyntaxHighlight",
        "hardBreak",
    ],
    "placeholderText": "Begin typing here...",  # set None to skip display
    "unsavedChangesWarningText": "You have unsaved changes!",  # set None to skip display
    "lang": "EN",
    "custom_extensions": [
        {
            "source_static": "my_custom_extension/my_custom_extension.js",
            "module_name": "MyCustomExtension",
            "toolbar_include": "my_custom_extension/my_custom_extension_toolbar_include.html",
            "buttonsconfig_include": "my_custom_extension/my_custom_extension_button_config.js",
            "css_include": "my_custom_extension/my_custom_extension.css",
        }
    ],
    "tiptapOutputFormat": "html",
}



# Generated by Django 3.2 on 2021-04-19 22:51

from django.db import migrations

import django_tiptap.fields


class Migration(migrations.Migration):

    dependencies = [
        ("demo_app", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="note",
            name="somethingMore",
            field=django_tiptap.fields.TipTapTextField(null=True),
        ),
    ]



from typing import Any, Dict

from django import forms
from django.conf import settings

from .config import TIPTAP_DEFAULT_CONFIG, getUpdatedContextForProperty


class TipTapWidget(forms.Textarea):
    class Media:
        css = {"all": ("django_tiptap/css/styles.css",)}

    template_name = "forms/tiptap_textarea.html"

    def __init__(self, config: dict = None, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.config = self.set_config(config)

    @staticmethod
    def set_config(config: dict = None) -> dict:
        # Take default config and update it with the user config from settings.py.

        config = config.copy() if config else TIPTAP_DEFAULT_CONFIG.copy()
        django_settings_config = getattr(settings, "DJANGO_TIPTAP_CONFIG", {})
        config.update(django_settings_config)

        return config

    def get_context(self, *args, **kwargs) -> Dict[str, Any]:
        context = super().get_context(*args, **kwargs)
        context["widget"]["config"] = self.config

        context = getUpdatedContextForProperty(context, "tooltips")

        context = getUpdatedContextForProperty(context, "translations")

        return context



from typing import Any, Dict

TIPTAP_DEFAULT_CONFIG = {
    "width": "500px",
    "height": "500px",
    "extensions": [
        "bold",
        "italic",
        "underline",
        "strikethrough",
        "h1",
        "h2",
        "h3",
        "h4",
        "h5",
        "h6",
        "textAlign",
        "indent",
        "table",
        "bulletList",
        "orderedList",
        "typography",
        "clearFormat",
        "jinjaSyntaxHighlight",
    ],
    "placeholderText": "Begin typing here...",
    "unsavedChangesWarningText": None,
    "lang": "EN",
    "custom_extensions": [],
    "tiptapOutputFomat": "html",
}

TIPTAP_DEFAULT_TOOLTIPS = {
    "EN": {
        "bold": "Bold | (ctrl / ⌘) + B",
        "italic": "Italic | (ctrl / ⌘) + I",
        "underline": "Underline | (ctrl / ⌘) + U",
        "strike": "Strikethrough | (ctrl / ⌘) + shift + X",
        "h1": "Header 1 | (ctrl + alt) / (⌘ + ⌥) + 1",
        "h2": "Header 2 | (ctrl + alt) / (⌘ + ⌥) + 2",
        "h3": "Header 3 | (ctrl + alt) / (⌘ + ⌥) + 3",
        "h4": "Header 4 | (ctrl + alt) / (⌘ + ⌥) + 4",
        "h5": "Header 5 | (ctrl + alt) / (⌘ + ⌥) + 5",
        "h6": "Header 6 | (ctrl + alt) / (⌘ + ⌥) + 6",
        "alignLeft": "Align Left | (ctrl + shift ⇧) / (⌘ + shift ⇧) + L",
        "alignCenter": "Align Center | (ctrl + shift ⇧) / (⌘ + shift ⇧) + E",
        "alignRight": "Align Right | (ctrl + shift ⇧) / (⌘ + shift ⇧) + R",
        "alignJustify": "Justify | (ctrl + shift ⇧) / (⌘ + shift ⇧) + J",
        "indent": "Indent (Tab ↹)",
        "outdent": "Outdent (shift ⇧ + Tab ↹)",
        "bulletList": "Bullet List | (ctrl + shift ⇧) / (⌘ + shift ⇧) + 8",
        "orderedList": "Numbered List | (ctrl + shift ⇧) / (⌘ + shift ⇧) + 7",
        "addTable": "Add Table",
        "deleteTable": "Delete Table",
        "addColumnBefore": "Add Column Before",
        "addColumnAfter": "Add Column After",
        "deleteColumn": "Delete Column",
        "addRowBefore": "Add Row Before",
        "addRowAfter": "Add Row After",
        "deleteRow": "Delete Row",
        "mergeCells": "Merge Cells",
        "splitCell": "Split Cell",
        "toggleHeaderColumn": "Toggle Header Column",
        "toggleHeaderRow": "Toggle Header Row",
        "toggleHeaderCell": "Toggle Header Cell",
        "toggleTableBorders": "Toggle Table Borders",
        "clearFormat": "Clear Format",
        "jinjaHighlight": "Jinja Highlight",
        "rows": "Rows",
        "columns": "Columns",
        "spellcheck": "Toggle Spellcheck",
    },
    "DE": {
        "bold": "Fett | (ctrl / ⌘) + B",
        "italic": "Kursiv | (ctrl / ⌘) + I",
        "underline": "Unterstrichen | (ctrl / ⌘) + U",
        "strike": "Durchstreichen | (ctrl / ⌘) + Umschalt + X",
        "h1": "Überschrift 1 | (ctrl + alt) / (⌘ + ⌥) + 1",
        "h2": "Überschrift 2 | (ctrl + alt) / (⌘ + ⌥) + 2",
        "h3": "Überschrift 3 | (ctrl + alt) / (⌘ + ⌥) + 3",
        "h4": "Überschrift 4 | (ctrl + alt) / (⌘ + ⌥) + 4",
        "h5": "Überschrift 5 | (ctrl + alt) / (⌘ + ⌥) + 5",
        "h6": "Überschrift 6 | (ctrl + alt) / (⌘ + ⌥) + 6",
        "alignLeft": "Linksbündig | (ctrl + Umschalt ⇧) / (⌘ + Umschalt ⇧) + L",
        "alignCenter": "Zentriert | (ctrl + Umschalt ⇧) / (⌘ + Umschalt ⇧) + E",
        "alignRight": "Rechtsbündig | (ctrl + Umschalt ⇧) / (⌘ + Umschalt ⇧) + R",
        "alignJustify": "Blocksatz | (ctrl + Umschalt ⇧) / (⌘ + Umschalt ⇧) + J",
        "indent": "Einrücken (Tab ↹)",
        "outdent": "Ausrücken (Umschalt ⇧ + Tab ↹)",
        "bulletList": "Aufzählungsliste | (ctrl + Umschalt ⇧) / (⌘ + Umschalt ⇧) + 8",
        "orderedList": "Nummerierte Liste | (ctrl + Umschalt ⇧) / (⌘ + Umschalt ⇧) + 7",
        "addTable": "Tabelle hinzufügen",
        "deleteTable": "Tabelle löschen",
        "addColumnBefore": "Spalte links einfügen",
        "addColumnAfter": "Spalte rechts einfügen",
        "deleteColumn": "Spalte löschen",
        "addRowBefore": "Zeile darüber einfügen",
        "addRowAfter": "Zeile darunter einfügen",
        "deleteRow": "Zeile löschen",
        "mergeCells": "Zellen zusammenführen",
        "splitCell": "Zelle aufteilen",
        "toggleHeaderColumn": "Kopfspalte ein/ausschalten",
        "toggleHeaderRow": "Kopfzeile ein/auschalten",
        "toggleHeaderCell": "Kopfzelle ein/auschalten",
        "toggleTableBorders": "Ränder ein/ausblenden",
        "clearFormat": "Formatierung entfernen",
        "jinjaHighlight": "Jinja Markierungen",
        "rows": "Zeilen",
        "columns": "Column",
        "spellcheck": "Rechtschreibprüfung ein/ausschalten",
    },
}

TIPTAP_DEFAULT_TRANSLATIONS = {
    "EN": {"row": "Row", "column": "Column", "add": "Add"},
    "DE": {"row": "Zeile", "column": "Spalte", "add": "Hinzufügen"},
}


def getUpdatedContextForProperty(context: dict, property: str) -> Dict[str, Any]:
    ctx = context.copy()

    if property in ctx["widget"]["config"]:
        return ctx
    elif "lang" in ctx["widget"]["config"]:
        langs: list = ["EN", "DE"]
        givenLang: str = ctx["widget"]["config"].get("lang")

        if givenLang.upper() in langs:
            ctx["widget"]["config"][property] = TIPTAP_DEFAULT_TOOLTIPS.copy()[
                givenLang.upper()
            ]
        else:
            ctx["widget"]["config"][property] = TIPTAP_DEFAULT_TOOLTIPS.copy()["EN"]
            print(
                "\n *** The language given to django_tiptap was not found, "
                "using english as default. *** \n"
            )
    else:
        ctx["widget"]["config"][property] = TIPTAP_DEFAULT_TOOLTIPS.copy()["EN"]

    return ctx



# Generated by Django 3.0.14 on 2021-06-30 12:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("demo_app", "0002_note_somethingmore"),
    ]

    operations = [
        migrations.AlterField(
            model_name="note",
            name="id",
            field=models.AutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
    ]



#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['django_tiptap']

package_data = \
{'': ['*'],
 'django_tiptap': ['static/*',
                   'static/django_tiptap/*',
                   'static/django_tiptap/css/*',
                   'templates/*',
                   'templates/forms/*']}

install_requires = \
['Django >= 2.2']

extras_require = \
{'dev': ['black', 'isort', 'pre-commit'], 'test': ['pytest']}

setup(name='django_tiptap',
      version='0.0.18',
      description='TipTap Editor in Django 🚀',
      author='Jeet Mandaliya & Max Patzelt',
      author_email='django.tiptap@gmail.com',
      url=None,
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      extras_require=extras_require,
      python_requires='>=3.5',
     )
